==> open-cluster-management-apps-model-6.3.0-sources.jar: io/fabric8/openclustermanagement/api/model/multicloudoperatorssubscription/apps/helmrelease/v1/HelmAppStatusFluent.java <==
package io.fabric8.openclustermanagement.api.model.multicloudoperatorssubscription.apps.helmrelease.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface HelmAppStatusFluent<A extends HelmAppStatusFluent<A>> extends Fluent<A>{
  public A addToConditions(Integer index,HelmAppCondition item);
  public A setToConditions(Integer index,HelmAppCondition item);
  public A addToConditions(io.fabric8.openclustermanagement.api.model.multicloudoperatorssubscription.apps.helmrelease.v1.HelmAppCondition... items);
  public A addAllToConditions(Collection<HelmAppCondition> items);
  public A removeFromConditions(io.fabric8.openclustermanagement.api.model.multicloudoperatorssubscription.apps.helmrelease.v1.HelmAppCondition... items);
  public A removeAllFromConditions(Collection<HelmAppCondition> items);
  public A removeMatchingFromConditions(Predicate<HelmAppConditionBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildConditions instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<HelmAppCondition> getConditions();
  public List<HelmAppCondition> buildConditions();
  public HelmAppCondition buildCondition(Integer index);
  public HelmAppCondition buildFirstCondition();
  public HelmAppCondition buildLastCondition();
  public HelmAppCondition buildMatchingCondition(Predicate<HelmAppConditionBuilder> predicate);
  public Boolean hasMatchingCondition(Predicate<HelmAppConditionBuilder> predicate);
  public A withConditions(List<HelmAppCondition> conditions);
  public A withConditions(io.fabric8.openclustermanagement.api.model.multicloudoperatorssubscription.apps.helmrelease.v1.HelmAppCondition... conditions);
  public Boolean hasConditions();
  public A addNewCondition(String lastTransitionTime,String message,String reason,String status,String type);
  public HelmAppStatusFluent.ConditionsNested<A> addNewCondition();
  public HelmAppStatusFluent.ConditionsNested<A> addNewConditionLike(HelmAppCondition item);
  public HelmAppStatusFluent.ConditionsNested<A> setNewConditionLike(Integer index,HelmAppCondition item);
  public HelmAppStatusFluent.ConditionsNested<A> editCondition(Integer index);
  public HelmAppStatusFluent.ConditionsNested<A> editFirstCondition();
  public HelmAppStatusFluent.ConditionsNested<A> editLastCondition();
  public HelmAppStatusFluent.ConditionsNested<A> editMatchingCondition(Predicate<HelmAppConditionBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildDeployedRelease instead.
   * @return The buildable object.
   */
  @Deprecated
  public HelmAppRelease getDeployedRelease();
  public HelmAppRelease buildDeployedRelease();
  public A withDeployedRelease(HelmAppRelease deployedRelease);
  public Boolean hasDeployedRelease();
  public A withNewDeployedRelease(String manifest,String name);
  public HelmAppStatusFluent.DeployedReleaseNested<A> withNewDeployedRelease();
  public HelmAppStatusFluent.DeployedReleaseNested<A> withNewDeployedReleaseLike(HelmAppRelease item);
  public HelmAppStatusFluent.DeployedReleaseNested<A> editDeployedRelease();
  public HelmAppStatusFluent.DeployedReleaseNested<A> editOrNewDeployedRelease();
  public HelmAppStatusFluent.DeployedReleaseNested<A> editOrNewDeployedReleaseLike(HelmAppRelease item);
  public interface ConditionsNested<N> extends Nested<N>,HelmAppConditionFluent<HelmAppStatusFluent.ConditionsNested<N>>{
    public N and();
    public N endCondition();
    
  }
  public interface DeployedReleaseNested<N> extends Nested<N>,HelmAppReleaseFluent<HelmAppStatusFluent.DeployedReleaseNested<N>>{
    public N and();
    public N endDeployedRelease();
    
  }
  
}

==> open-cluster-management-apps-model-6.7.0-sources.jar: io/fabric8/openclustermanagement/api/model/multicloudoperatorssubscription/apps/helmrelease/v1/HelmAppStatusFluent.java <==
package io.fabric8.openclustermanagement.api.model.multicloudoperatorssubscription.apps.helmrelease.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface HelmAppStatusFluent<A extends HelmAppStatusFluent<A>> extends Fluent<A>{
  public A addToConditions(int index,HelmAppCondition item);
  public A setToConditions(int index,HelmAppCondition item);
  public A addToConditions(io.fabric8.openclustermanagement.api.model.multicloudoperatorssubscription.apps.helmrelease.v1.HelmAppCondition... items);
  public A addAllToConditions(Collection<HelmAppCondition> items);
  public A removeFromConditions(io.fabric8.openclustermanagement.api.model.multicloudoperatorssubscription.apps.helmrelease.v1.HelmAppCondition... items);
  public A removeAllFromConditions(Collection<HelmAppCondition> items);
  public A removeMatchingFromConditions(Predicate<HelmAppConditionBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildConditions instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<HelmAppCondition> getConditions();
  public List<HelmAppCondition> buildConditions();
  public HelmAppCondition buildCondition(int index);
  public HelmAppCondition buildFirstCondition();
  public HelmAppCondition buildLastCondition();
  public HelmAppCondition buildMatchingCondition(Predicate<HelmAppConditionBuilder> predicate);
  public Boolean hasMatchingCondition(Predicate<HelmAppConditionBuilder> predicate);
  public A withConditions(List<HelmAppCondition> conditions);
  public A withConditions(io.fabric8.openclustermanagement.api.model.multicloudoperatorssubscription.apps.helmrelease.v1.HelmAppCondition... conditions);
  public Boolean hasConditions();
  public A addNewCondition(String lastTransitionTime,String message,String reason,String status,String type);
  public HelmAppStatusFluent.ConditionsNested<A> addNewCondition();
  public HelmAppStatusFluent.ConditionsNested<A> addNewConditionLike(HelmAppCondition item);
  public HelmAppStatusFluent.ConditionsNested<A> setNewConditionLike(int index,HelmAppCondition item);
  public HelmAppStatusFluent.ConditionsNested<A> editCondition(int index);
  public HelmAppStatusFluent.ConditionsNested<A> editFirstCondition();
  public HelmAppStatusFluent.ConditionsNested<A> editLastCondition();
  public HelmAppStatusFluent.ConditionsNested<A> editMatchingCondition(Predicate<HelmAppConditionBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildDeployedRelease instead.
   * @return The buildable object.
   */
  @Deprecated
  public HelmAppRelease getDeployedRelease();
  public HelmAppRelease buildDeployedRelease();
  public A withDeployedRelease(HelmAppRelease deployedRelease);
  public Boolean hasDeployedRelease();
  public A withNewDeployedRelease(String manifest,String name);
  public HelmAppStatusFluent.DeployedReleaseNested<A> withNewDeployedRelease();
  public HelmAppStatusFluent.DeployedReleaseNested<A> withNewDeployedReleaseLike(HelmAppRelease item);
  public HelmAppStatusFluent.DeployedReleaseNested<A> editDeployedRelease();
  public HelmAppStatusFluent.DeployedReleaseNested<A> editOrNewDeployedRelease();
  public HelmAppStatusFluent.DeployedReleaseNested<A> editOrNewDeployedReleaseLike(HelmAppRelease item);
  public interface ConditionsNested<N> extends Nested<N>,HelmAppConditionFluent<HelmAppStatusFluent.ConditionsNested<N>>{
    public N and();
    public N endCondition();
    
  }
  public interface DeployedReleaseNested<N> extends Nested<N>,HelmAppReleaseFluent<HelmAppStatusFluent.DeployedReleaseNested<N>>{
    public N and();
    public N endDeployedRelease();
    
  }
  
}
